# ECL API

::: creditriskengine.ecl.ifrs9.ecl_calc
::: creditriskengine.ecl.ifrs9.staging
::: creditriskengine.ecl.ifrs9.sicr

## Revolving Credit ECL

::: creditriskengine.ecl.ifrs9.revolving.ecl_revolving
::: creditriskengine.ecl.ifrs9.revolving.ccf
::: creditriskengine.ecl.ifrs9.revolving.behavioral_life
::: creditriskengine.ecl.ifrs9.revolving.ead_profile
::: creditriskengine.ecl.ifrs9.revolving.provision_floors
::: creditriskengine.ecl.ifrs9.revolving.product_config
